@@ -15,10 +15,10 @@
 # under the License.
 import sys
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
+import designate.conf
 from designate import hookpoints
 from designate import service
 from designate import utils
@@ -26,9 +26,8 @@ from designate import version
 from designate.mdns import service as mdns_service
 
 
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 CONF.import_opt('workers', 'designate.mdns', group='service:mdns')
-CONF.import_opt('threads', 'designate.mdns', group='service:mdns')
 
 
 def main():
@@ -38,6 +37,8 @@ def main():
 
     hookpoints.log_hook_setup()
 
-    server = mdns_service.Service(threads=CONF['service:mdns'].threads)
+    server = mdns_service.Service()
+    heartbeat = service.Heartbeat(server.service_name)
     service.serve(server, workers=CONF['service:mdns'].workers)
+    heartbeat.start()
     service.wait()
