@@ -14,7 +14,6 @@
 #    under the License.
 #
 # Copied partially from nova
-
 from neutronclient.v2_0 import client as clientv20
 from neutronclient.common import exceptions as neutron_exceptions
 from oslo_config import cfg
@@ -22,8 +21,6 @@ from oslo_log import log as logging
 from oslo_service import threadgroup
 
 from designate import exceptions
-from designate.i18n import _LW
-from designate.i18n import _LE
 from designate.network_api import base
 
 
@@ -31,44 +28,6 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-neutron_group = cfg.OptGroup(
-            name='network_api:neutron', title="Configuration network api"
-        )
-
-neutron_opts = [
-    cfg.ListOpt('endpoints',
-                help='URL to use if None in the ServiceCatalog that is '
-                'passed by the request context. Format: <region>|<url>'),
-    cfg.StrOpt('endpoint_type', default='publicURL',
-               help="Endpoint type to use"),
-    cfg.IntOpt('timeout',
-               default=30,
-               help='timeout value for connecting to neutron in seconds'),
-    cfg.StrOpt('admin_username',
-               help='username for connecting to neutron in admin context'),
-    cfg.StrOpt('admin_password',
-               help='password for connecting to neutron in admin context',
-               secret=True),
-    cfg.StrOpt('admin_tenant_name',
-               help='tenant name for connecting to neutron in admin context'),
-    cfg.StrOpt('auth_url',
-               help='auth url for connecting to neutron in admin context'),
-    cfg.BoolOpt('insecure',
-                default=False,
-                help='if set, ignore any SSL validation issues'),
-    cfg.StrOpt('auth_strategy',
-               default='keystone',
-               help='auth strategy for connecting to '
-                    'neutron in admin context'),
-    cfg.StrOpt('ca_certificates_file',
-               help='Location of ca certificates file to use for '
-                    'neutron client requests.'),
-]
-
-cfg.CONF.register_group(neutron_group)
-cfg.CONF.register_opts(neutron_opts, group=neutron_group)
-
-
 def get_client(context, endpoint):
     params = {
         'endpoint_url': endpoint,
@@ -82,7 +41,7 @@ def get_client(context, endpoint):
         params['auth_strategy'] = None
     elif CONF['network_api:neutron'].admin_username is not None:
         params['username'] = CONF['network_api:neutron'].admin_username
-        params['tenant_name'] = CONF['network_api:neutron'].admin_tenant_name
+        params['project_name'] = CONF['network_api:neutron'].admin_tenant_name
         params['password'] = CONF['network_api:neutron'].admin_password
         params['auth_url'] = CONF['network_api:neutron'].auth_url
         params['auth_strategy'] = CONF['network_api:neutron'].auth_strategy
@@ -121,13 +80,12 @@ class NeutronNetworkAPI(base.NetworkAPI):
                 # NOTE: 401 might be that the user doesn't have neutron
                 # activated in a particular region, we'll just log the failure
                 # and go on with our lives.
-                LOG.warning(_LW("Calling Neutron resulted in a 401, "
-                                "please investigate."))
+                LOG.warning("Calling Neutron resulted in a 401, "
+                            "please investigate.")
                 LOG.exception(e)
                 return
             except Exception as e:
-                LOG.error(_LE('Failed calling Neutron '
-                              '%(region)s - %(endpoint)s'),
+                LOG.error('Failed calling Neutron %(region)s - %(endpoint)s',
                           {'region': region, 'endpoint': endpoint})
                 LOG.exception(e)
                 failed.append((e, endpoint, region))
@@ -145,7 +103,7 @@ class NeutronNetworkAPI(base.NetworkAPI):
 
         for endpoint, region in endpoints:
             tg.add_thread(_call, endpoint, region,
-                          tenant_id=context.tenant)
+                          project_id=context.project_id)
         tg.wait()
 
         # NOTE: Sadly tg code doesn't give us a good way to handle failures.
