@@ -20,46 +20,41 @@ import inspect
 import os
 import time
 
-from testtools import testcase
-from oslotest import base
-from oslo_log import log as logging
+import eventlet
 from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
+from oslo_log import log as logging
 from oslo_messaging import conffixture as messaging_fixture
+from oslotest import base
+from testtools import testcase
 
-from designate import policy
-from designate import utils
+import designate.conf
 from designate import exceptions
 from designate import objects
+from designate import policy
 from designate import storage
+from designate import utils
 from designate.context import DesignateContext
+from designate.manage import database as manage_database
 from designate.tests import fixtures
 from designate.tests import resources
-from designate.manage import database as manage_database
-
-import eventlet
 
 eventlet.monkey_patch(os=False)
 
-
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
-cfg.CONF.import_opt('storage_driver', 'designate.central',
-                    group='service:central')
-cfg.CONF.import_opt('auth_strategy', 'designate.api',
-                    group='service:api')
-cfg.CONF.import_opt('connection', 'designate.storage.impl_sqlalchemy',
-                    group='storage:sqlalchemy')
-cfg.CONF.import_opt('cache_driver', 'designate.pool_manager',
-                    group='service:pool_manager')
-cfg.CONF.import_opt('connection',
-                    'designate.pool_manager.cache.impl_sqlalchemy',
-                    group='pool_manager_cache:sqlalchemy')
-cfg.CONF.import_opt('emitter_type', 'designate.service_status',
-                    group="heartbeat_emitter")
-cfg.CONF.import_opt('scheduler_filters', 'designate.scheduler',
-                    group="service:central")
-default_pool_id = cfg.CONF['service:central'].default_pool_id
+CONF.import_opt('storage_driver', 'designate.central',
+                group='service:central')
+CONF.import_opt('auth_strategy', 'designate.api',
+                group='service:api')
+CONF.import_opt('connection', 'designate.storage.impl_sqlalchemy',
+                group='storage:sqlalchemy')
+CONF.import_opt('emitter_type', 'designate.service_status',
+                group="heartbeat_emitter")
+CONF.import_opt('scheduler_filters', 'designate.scheduler',
+                group="service:central")
+default_pool_id = CONF['service:central'].default_pool_id
 
 _TRUE_VALUES = ('true', '1', 'yes', 'y')
 
@@ -76,6 +71,13 @@ class TestCase(base.BaseTestCase):
         'status': "UP",
         'stats': {},
         'capabilities': {},
+    }, {
+        'id': 'c326f735-eecc-4968-969f-355a43c4ae27',
+        'service_name': 'baz',
+        'hostname': 'qux',
+        'status': "UP",
+        'stats': {},
+        'capabilities': {},
     }]
 
     quota_fixtures = [{
@@ -320,16 +322,19 @@ class TestCase(base.BaseTestCase):
     def setUp(self):
         super(TestCase, self).setUp()
 
-        self.CONF = self.useFixture(cfg_fixture.Config(cfg.CONF)).conf
+        self.CONF = self.useFixture(cfg_fixture.Config(CONF)).conf
 
-        self.messaging_conf = messaging_fixture.ConfFixture(cfg.CONF)
-        self.messaging_conf.transport_driver = 'fake'
+        self.messaging_conf = messaging_fixture.ConfFixture(CONF)
+        self.messaging_conf.transport_url = 'fake:/'
         self.messaging_conf.response_timeout = 5
         self.useFixture(self.messaging_conf)
 
-        self.config(notification_driver=['test'])
+        self.config(
+            driver=['test'],
+            group='oslo_messaging_notifications'
+        )
 
-        self.useFixture(fixtures.RPCFixture(cfg.CONF))
+        self.useFixture(fixtures.RPCFixture(CONF))
 
         self.config(
             storage_driver='sqlalchemy',
@@ -367,8 +372,6 @@ class TestCase(base.BaseTestCase):
             group='storage:sqlalchemy'
         )
 
-        self._setup_pool_manager_cache()
-
         self.config(network_api='fake')
 
         self.config(
@@ -377,7 +380,6 @@ class TestCase(base.BaseTestCase):
 
         # "Read" Configuration
         self.CONF([], project='designate')
-        utils.register_plugin_opts()
 
         self.useFixture(fixtures.PolicyFixture())
         self.network_api = fixtures.NetworkAPIFixture()
@@ -385,37 +387,12 @@ class TestCase(base.BaseTestCase):
         self.central_service = self.start_service('central')
 
         self.admin_context = self.get_admin_context()
-        storage_driver = cfg.CONF['service:central'].storage_driver
+        storage_driver = CONF['service:central'].storage_driver
         self.storage = storage.get_storage(storage_driver)
 
         # Setup the Default Pool with some useful settings
         self._setup_default_pool()
 
-    def _setup_pool_manager_cache(self):
-
-        self.config(
-            cache_driver='sqlalchemy',
-            group='service:pool_manager')
-
-        repository = os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                                  '..',
-                                                  'pool_manager',
-                                                  'cache',
-                                                  'impl_sqlalchemy',
-                                                  'migrate_repo'))
-        db_fixture = self.useFixture(
-            fixtures.DatabaseFixture.get_fixture(repository))
-
-        if os.getenv('DESIGNATE_SQL_DEBUG', "False").lower() in _TRUE_VALUES:
-            connection_debug = 50
-        else:
-            connection_debug = 0
-
-        self.config(
-            connection=db_fixture.url,
-            connection_debug=connection_debug,
-            group='pool_manager_cache:sqlalchemy')
-
     def _setup_default_pool(self):
         # Fetch the default pool
         pool = self.storage.get_pool(self.admin_context, default_pool_id)
@@ -461,8 +438,8 @@ class TestCase(base.BaseTestCase):
 
     def get_admin_context(self):
         return DesignateContext.get_admin_context(
-            tenant=utils.generate_uuid(),
-            user=utils.generate_uuid())
+            project_id=utils.generate_uuid(),
+            user_id=utils.generate_uuid())
 
     # Fixture methods
     def get_quota_fixture(self, fixture=0, values=None):
@@ -685,7 +662,7 @@ class TestCase(base.BaseTestCase):
                                        fixture=fixture, values=kwargs)
 
         if 'tenant_id' not in values:
-            values['tenant_id'] = context.tenant
+            values['tenant_id'] = context.project_id
 
         return self.central_service.create_zone(
             context, objects.Zone.from_dict(values))
@@ -732,7 +709,7 @@ class TestCase(base.BaseTestCase):
         values = self.get_pool_fixture(fixture=fixture, values=kwargs)
 
         if 'tenant_id' not in values:
-            values['tenant_id'] = context.tenant
+            values['tenant_id'] = context.project_id
 
         return self.central_service.create_pool(
             context, objects.Pool.from_dict(values))
@@ -771,7 +748,7 @@ class TestCase(base.BaseTestCase):
         values = {}
 
         if 'tenant_id' not in values:
-            values['tenant_id'] = context.tenant
+            values['tenant_id'] = context.project_id
 
         if 'zone_transfer_request_id' not in values:
             values['zone_transfer_request_id'] = zone_transfer_request.id
@@ -790,7 +767,7 @@ class TestCase(base.BaseTestCase):
         fixture = kwargs.pop('fixture', 0)
 
         zone_import = self.get_zone_import_fixture(fixture=fixture,
-                                               values=kwargs)
+                                                   values=kwargs)
 
         return self.storage.create_zone_import(
             context, objects.ZoneImport.from_dict(zone_import))
@@ -800,7 +777,7 @@ class TestCase(base.BaseTestCase):
         fixture = kwargs.pop('fixture', 0)
 
         zone_export = self.get_zone_export_fixture(fixture=fixture,
-                                               values=kwargs)
+                                                   values=kwargs)
 
         return self.storage.create_zone_export(
             context, objects.ZoneExport.from_dict(zone_export))
